@@ -187,7 +187,7 @@ KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
 
   KActionCollection *coll = dir->actionCollection();
   // some shortcuts of diroperator that clashes with Kate
-  coll->action( "delete" )->setShortcut( Qt::ALT + Qt::Key_Delete );
+  coll->action( "trash" )->setShortcut( Qt::ALT + Qt::Key_Delete );
   coll->action( "reload" )->setShortcut( Qt::ALT + Qt::Key_F5 );
   coll->action( "back" )->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Left );
   coll->action( "forward" )->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Right );
@@ -300,6 +300,7 @@ void ::KateFileSelector::readSessionConfig(KConfigBase *config, const QString &
 
   KConfigGroup cgDir(config, name + ":dir");
   dir->readConfig(cgDir);
+  dir->setView(KFile::Default);
 
   KConfigGroup cg (config, name );
   cmbPath->setUrls( cg.readPathEntry( "dir history", QStringList() ) );
